summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authortrawick <trawick@13f79535-47bb-0310-9956-ffa450edef68>2004-06-23 12:20:44 +0000
committertrawick <trawick@13f79535-47bb-0310-9956-ffa450edef68>2004-06-23 12:20:44 +0000
commit30657c4f011350df7489c3d7e5ba018ecf3c9cc9 (patch)
tree343a492c412dbe3195a865b3a4be4a3ef95fa689 /include
parentdff74a633a0eb6e9452c3fe9615f273f61082c6f (diff)
downloadlibapr-30657c4f011350df7489c3d7e5ba018ecf3c9cc9.tar.gz
Add command type APR_SHELLCMD_ENV for creating a process
which is started by the shell and which inherits the parent's environment variables. The immediate use for this is with Apache httpd's piped loggers, correcting a regression since 1.3. In general, applications starting child processes often want the child to run with the same environment variables, so this plugs a hole in the API. git-svn-id: http://svn.apache.org/repos/asf/apr/apr/trunk@65213 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'include')
-rw-r--r--include/apr_thread_proc.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/include/apr_thread_proc.h b/include/apr_thread_proc.h
index 47e443c3b..68ced433b 100644
--- a/include/apr_thread_proc.h
+++ b/include/apr_thread_proc.h
@@ -45,7 +45,10 @@ typedef enum {
APR_SHELLCMD, /**< use the shell to invoke the program */
APR_PROGRAM, /**< invoke the program directly, no copied env */
APR_PROGRAM_ENV, /**< invoke the program, replicating our environment */
- APR_PROGRAM_PATH /**< find program on PATH, use our environment */
+ APR_PROGRAM_PATH, /**< find program on PATH, use our environment */
+ APR_SHELLCMD_ENV, /**< use the shell to invoke the program,
+ * replicating our environment
+ */
} apr_cmdtype_e;
typedef enum {
@@ -546,8 +549,8 @@ APR_DECLARE(apr_status_t) apr_proc_fork(apr_proc_t *proc, apr_pool_t *cont);
* one should be the program name.
* @param env The new environment table for the new process. This
* should be a list of NULL-terminated strings. This argument
* is ignored for APR_PROGRAM_ENV and APR_PROGRAM_PATH types
* of commands.
* @param attr the procattr we should use to determine how to create the new
* process
* @param pool The pool to use.
@@ -546,8 +549,8 @@ APR_DECLARE(apr_status_t) apr_proc_fork(apr_proc_t *proc, apr_pool_t *cont);
* @param env The new environment table for the new process. This
* should be a list of NULL-terminated strings. This argument
- * is ignored for APR_PROGRAM_ENV and APR_PROGRAM_PATH types
- * of commands.
+ * is ignored for APR_PROGRAM_ENV, APR_PROGRAM_PATH, and
+ * APR_SHELLCMD_ENV types of commands.
* @param attr the procattr we should use to determine how to create the new
* process